<?php
// src/OgBootBundle/Service/CurlRequestService.php

namespace App\OgBootBundle\Service;
use Exception;

class CurlRequestService
{

    public function convertMaskToCIDR($mask)
    {
        $bits = 0;
        $mask = explode(".", $mask);

        foreach ($mask as $octect)
            $bits += strlen(str_replace("0", "", decbin($octect)));

        return $bits;
    }

// src/Service/CurlRequestService.php

public function installOglive($isoname)
{
    $socketPath = '/tmp/oglive_daemon.sock';
    $socket = socket_create(AF_UNIX, SOCK_STREAM, 0);
    if ($socket === false) {
        syslog(LOG_ERR, 'Error al crear el socket: ' . socket_strerror(socket_last_error()));
        return ['success' => false, 'output' => 'Error al crear el socket'];
    }

    $result = socket_connect($socket, $socketPath);
    if ($result === false) {
        syslog(LOG_ERR, 'Error al conectar con el socket: ' . socket_strerror(socket_last_error($socket)));
        socket_close($socket);
        return ['success' => false, 'output' => 'Error al conectar con el socket'];
    }

    $command = [
        'action' => 'download',
        'args' => [$isoname]
    ];

    socket_write($socket, json_encode($command), strlen(json_encode($command)));

    $response = '';
    $status = [];

    while ($buffer = socket_read($socket, 2048)) {
        $response .= $buffer;
        $status[] = json_decode($buffer, true);
    }

    socket_close($socket);

    // Analiza el último estado recibido
    $lastStatus = end($status);
    if ($lastStatus && $lastStatus['status'] === 'completed') {
        return ['success' => true, 'output' => $lastStatus];
    } else {
        return ['success' => false, 'output' => $status];
    }
}



public function callOgLive($parameter)
{
    $socketPath = '/tmp/oglive_daemon.sock'; // Path to the UNIX socket
    $socket = socket_create(AF_UNIX, SOCK_STREAM, 0);
    if ($socket === false) {
        syslog(LOG_ERR, 'Error al crear el socket: ' . socket_strerror(socket_last_error()));
        return [
            'success' => false,
            'error' => 'Error al crear el socket'
        ];
    }

    $result = socket_connect($socket, $socketPath);
    if ($result === false) {
        syslog(LOG_ERR, 'Error al conectar con el socket: ' . socket_strerror(socket_last_error($socket)));
        socket_close($socket);
        return [
            'success' => false,
            'error' => 'Error al conectar con el socket'
        ];
    }

    $args = explode(' ', $parameter);
    $action = array_shift($args); // Toma la primera palabra como la acción
    $command = [
        'action' => $action,
        'args' => $args
    ];

    syslog(LOG_INFO, 'Sending command to daemon: ' . json_encode($command));
    socket_write($socket, json_encode($command), strlen(json_encode($command)));

    $response = '';
    while ($buffer = socket_read($socket, 2048)) {
        $response .= $buffer;
    }

    socket_close($socket);

    $decodedResponse = json_decode($response, true);

    if (isset($decodedResponse['success']) && $decodedResponse['success']) {
        return $decodedResponse['output'];
    } else {
        syslog(LOG_ERR, 'Error al ejecutar el comando: ' . $decodedResponse['error']);
        return [
            'success' => false,
            'error' => $decodedResponse['error'] ?? 'Unknown error'
        ];
    }
}




}
